import RPi.GPIO as GPIO # Import Raspberry Pi GPIO library
import time
from time import sleep # Import the sleep function from the time module

import Adafruit_GPIO.SPI as SPI
import Adafruit_SSD1306

from PIL import Image
from PIL import ImageDraw
from PIL import ImageFont

import subprocess

GPIO.setwarnings(False) # Ignore warning for now
GPIO.setmode(GPIO.BOARD) # Use physical pin numbering
#setup HC-SR04 Pint Sensor
TRIG = 16
ECHO = 18
GPIO.setup(TRIG,GPIO.OUT)
GPIO.setup(ECHO,GPIO.IN)

GPIO.output(TRIG, False)
print ("Calibrating.....")
time.sleep(2)

# SETUP RGB LED
LED_R = 13
LED_G = 15
LED_B = 11
GPIO.setup(LED_R, GPIO.OUT, initial=GPIO.LOW) # Set pin 8 to be an output pin and set initial value to low (off)
GPIO.setup(LED_G, GPIO.OUT, initial=GPIO.LOW) # Set pin 8 to be an output pin and set initial value to low (off)
GPIO.setup(LED_B, GPIO.OUT, initial=GPIO.LOW) # Set pin 8 to be an output pin and set initial value to low (off)

# SETUP SERVO-1
SERVO_1=7
GPIO.setup(SERVO_1, GPIO.OUT)
pwm1=GPIO.PWM(SERVO_1, 50)
# SETUP SERVO-2
SERVO_2=8
GPIO.setup(SERVO_2, GPIO.OUT)
pwm2=GPIO.PWM(SERVO_2, 50)

pwm1.start(0)
pwm2.start(0)

#setup OLED Display
# Raspberry Pi pin configuration:
RST = None     # on the PiOLED this pin isnt used
# Note the following are only used with SPI:
DC = 23
SPI_PORT = 0
SPI_DEVICE = 0

# 128x32 display with hardware I2C:
disp = Adafruit_SSD1306.SSD1306_128_32(rst=RST)

# Initialize library.
disp.begin()

# Clear display.
disp.clear()
disp.display()

# Create blank image for drawing.
# Make sure to create image with mode '1' for 1-bit color.
width = disp.width
height = disp.height
image = Image.new('1', (width, height))
# Get drawing object to draw on image.
draw = ImageDraw.Draw(image)

# Draw a black filled box to clear the image.
draw.rectangle((0,0,width,height), outline=0, fill=0)

# Draw some shapes.
# First define some constants to allow easy resizing of shapes.
padding = -2
top = padding
bottom = height-padding
# Move left to right keeping track of the current x position for drawing shapes.
x = 0
# Load default font.
font = ImageFont.load_default()

def setAngle(serv,angle):
    #duty = angle / 18 + 3
    duty = round(((angle/18) + 2.5),1)
    if serv==1 :
        GPIO.output(SERVO_1, True)
        pwm1.ChangeDutyCycle(duty)
        sleep(1)
        GPIO.output(SERVO_1, False)
        pwm1.ChangeDutyCycle(duty)
    else :
        GPIO.output(SERVO_2, True)
        pwm2.ChangeDutyCycle(duty)
        sleep(1)
        GPIO.output(SERVO_2, False)
        pwm2.ChangeDutyCycle(duty)




while True: # Run forever
 GPIO.output(LED_R, GPIO.HIGH) # Turn on
 sleep(.5) # Sleep for 1 second
 GPIO.output(LED_R, GPIO.LOW) # Turn off
 sleep(.5) # Sleep for 1 second
 GPIO.output(LED_G, GPIO.HIGH) # Turn on
 sleep(.5) # Sleep for 1 second
 GPIO.output(LED_G, GPIO.LOW) # Turn off
 sleep(.5) # Sleep for 1 second
 GPIO.output(LED_B, GPIO.HIGH) # Turn on
 sleep(.5) # Sleep for 1 second
 GPIO.output(LED_B, GPIO.LOW) # Turn off
 sleep(.5) # Sleep for 1 second
 disp.clear()
 disp.display()
 
 disp.image(image)
 disp.display()
 draw.text((0,  0), "Starting servo", font=font, fill=255)
 disp.display()
 
 print("servo start")
 setAngle(2,0) # left -90 deg position
 sleep(1)
 setAngle(2,90) # left -90 deg position
 sleep(1)
 setAngle(2,180) # left -90 deg position
 sleep(1)
 print("servo done")
 
 #calculate distance using ping sensor
 GPIO.output(TRIG, True)
 time.sleep(0.00001)
 GPIO.output(TRIG, False)
 while GPIO.input(ECHO)==0:
       pulse_start = time.time()

 while GPIO.input(ECHO)==1:
       pulse_end = time.time()

 pulse_duration = pulse_end - pulse_start
 distance = pulse_duration * 17150
 distance = round(distance+1.15, 2)
 print ("distance:",distance,"cm")
 time.sleep(1)
 draw.text((0, top+10), "Distance (cm): ", font=font, fill=255)
 draw.text((0, top+20), " "+str(distance),  font=font, fill=255)
 disp.display()
 time.sleep(.1)


pwm1.stop()
pwm2.stop()
GPIO.cleanup()